[gobject-introspection] [girepository] Update gtk-doc syntax



commit 14cee3d50f8588f93386cea07406b0e9a7290c7d
Author: Johan Dahlin <johan gnome org>
Date:   Tue May 18 13:37:51 2010 -0300

    [girepository] Update gtk-doc syntax
    
    Update the gtk-doc syntax to remove a couple of warnings

 girepository/ginfo.c        |   14 ++++++++------
 girepository/girepository.c |    2 +-
 girepository/gtypelib.h     |    2 +-
 3 files changed, 10 insertions(+), 8 deletions(-)
---
diff --git a/girepository/girepository.c b/girepository/girepository.c
index e7004a9..d4be01d 100644
--- a/girepository/girepository.c
+++ b/girepository/girepository.c
@@ -856,7 +856,7 @@ g_irepository_get_shared_library (GIRepository *repository,
 /**
  * g_irepository_get_c_prefix
  * @repository: A #GIRepository, may be %NULL for the default
- * @namespace: Namespace to inspect
+ * @namespace_: Namespace to inspect
  *
  * This function returns the "C prefix", or the C level namespace
  * associated with the given introspection namespace.  Each C symbol
diff --git a/girepository/gtypelib.h b/girepository/gtypelib.h
index 8208014..1ca83c8 100644
--- a/girepository/gtypelib.h
+++ b/girepository/gtypelib.h
@@ -717,7 +717,7 @@ typedef struct {
 } StructBlob;
 
 /**
- * UnionBlob;
+ * UnionBlob:
  * @unregistered: If this is set, the type is not registered with GType.
  * @discriminated: Is set if the union is discriminated
  * @alignment: The byte boundary that the union is aligned to in memory



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/girepository/ginfo.c b/girepository/ginfo.c
index 1d56a22..aab864d 100644
--- a/girepository/ginfo.c
+++ b/girepository/ginfo.c
@@ -30,7 +30,7 @@
 
 typedef struct _GIRealInfo GIRealInfo;
 
-/**
+/*
  * We just use one structure for all of the info object
  * types; in general, we should be reading data directly
  * from the typelib, and not having computed data in
@@ -437,7 +437,7 @@ find_first_attribute (GIRealInfo *rinfo)
 /**
  * g_base_info_iterate_attributes:
  * @info: A #GIBaseInfo
  * @iter: A #GIAttributeIter structure, must be initialized; see below
  * @name: (out) (transfer none): Returned name, must not be freed
  * @value: (out) (transfer none): Returned name, must not be freed
  *
@@ -469,7 +469,7 @@ find_first_attribute (GIRealInfo *rinfo)
  */
 gboolean
 g_base_info_iterate_attributes (GIBaseInfo       *info,
-                                 GIAttributeIter *iter,
+                                 GIAttributeIter *iterator,
                                  gchar           **name,
                                  gchar           **value)
 {
@@ -480,8 +480,8 @@ g_base_info_iterate_attributes (GIBaseInfo       *info,
   after = (AttributeBlob *) &rinfo->typelib->data[header->attributes +
                                                   header->n_attributes * header->attribute_blob_size];
 
-  if (iter->data != NULL)
-    next = (AttributeBlob *) iter->data;
+  if (iterator->data != NULL)
+    next = (AttributeBlob *) iterator->data;
   else
     next = find_first_attribute (rinfo);
 
@@ -490,7 +490,7 @@ g_base_info_iterate_attributes (GIBaseInfo       *info,
 
   *name = (gchar*) g_typelib_get_string (rinfo->typelib, next->name);
   *value = (gchar*) g_typelib_get_string (rinfo->typelib, next->value);
-  iter->data = next + 1;
+  iterator->data = next + 1;
 
   return TRUE;
 }
@@ -994,6 +994,8 @@ g_type_info_get_param_type (GITypeInfo *info,
  * this function returns full information about the referenced type.  You can then
  * inspect the type of the returned #GIBaseInfo to further query whether it is
  * a concrete GObject, a GInterface, a structure, etc. using g_base_info_get_type().
+ *
+ * Returns: a struct representing the interface or %NULL
  */
 GIBaseInfo *
 g_type_info_get_interface (GITypeInfo *info)
@@ -437,7 +437,7 @@ find_first_attribute (GIRealInfo *rinfo)
  * g_base_info_iterate_attributes:
  * @info: A #GIBaseInfo
- * @iter: A #GIAttributeIter structure, must be initialized; see below
+ * @iterator: A #GIAttributeIter structure, must be initialized; see below
  * @name: (out) (transfer none): Returned name, must not be freed
  * @value: (out) (transfer none): Returned name, must not be freed